==> inline-css-loader-2.0.1.tgz: package/lib/__tests__/main.js <==
'use strict';

var _ = require('..');

var _2 = _interopRequireDefault(_);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _babylon = require('babylon');

var _babelGenerator = require('babel-generator');

var _babelGenerator2 = _interopRequireDefault(_babelGenerator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getTree(input) {
  return (0, _babylon.parse)(input, { sourceType: 'module' });
}


function normalizeInput(input) {
  return (0, _babelGenerator2.default)(getTree(input), {
    minified: true
  }, input).code;
}

function runLoader(input) {
  return _2.default.call({
    generateOptions: {
      minified: true,
      quotes: 'single'
    }
  }, input);
}

function readFile(filePath) {
  return _fs2.default.readFileSync(_path2.default.resolve(__dirname, `${ filePath }.txt`), { encoding: 'utf8' });
}

describe('inline CSS Loader', () => {
  // const exportNodes = [];
  // exportNodes.push(readFile('exportNode/es5'));
  // exportNodes.push(readFile('exportNode/es6'));
  // exportNodes.push(readFile('exportNode/babel'));
  // exportNodes.push(readFile('exportNode/babelLoose'));
  // exportNodes.push(readFile('exportNode/babelSpread'));
  // exportNodes.push(readFile('exportNode/babelRuntimeSpread'));
  // exportNodes.push(readFile('exportNode/webpack'));
  // exportNodes.push(readFile('exportNode/webpack2'));
  // exportNodes.push(readFile('exportNode/webpack3'));
  // exportNodes.push(readFile('exportNode/webpack4'));
  // exportNodes.push(readFile('exportNode/webpack5'));
  // it('should find nodes', () => {
  //   exportNodes.forEach(n => {
  //     const tree = parseCode(n);
  //     expect(tree).toBeDefined();
  //     const root = inlineCssLoader.getExportsNode(tree.body);
  //     expect(root).toBeDefined();
  //     expect(root.type).toBe('ObjectExpression');
  //   });
  // });

  const fullparseCode = [];
  fullparseCode.push(readFile('fullObjects/simple'));
  fullparseCode.push(readFile('fullObjects/spread'));
  fullparseCode.push(readFile('fullObjects/media'));
  it('parseCode, doNothing', () => {
    fullparseCode.forEach(obj => {
      const generatedFromTree = normalizeInput(obj);
      expect(generatedFromTree).toBe(runLoader(obj));
    });
  });

  it('temp', () => {
    const temp = {
      input: readFile('transforms/complexIn'),
      output: readFile('transforms/complexOut')
    };
    const generatedFromTree = normalizeInput(temp.output);
    expect(generatedFromTree).toBe(runLoader(temp.input));
  });
  //
  const transforms = [];
  transforms.push({
    input: readFile('transforms/simpleIn'),
    output: readFile('transforms/simpleOut')
  });
  transforms.push({
    input: readFile('transforms/spreadIn'),
    output: readFile('transforms/spreadOut')
  });
  transforms.push({
    input: readFile('transforms/complexIn'),
    output: readFile('transforms/complexOut')
  });
  transforms.push({
    input: readFile('transforms/realIn'),
    output: readFile('transforms/realOut')
  });

  it('transforms', () => {
    transforms.forEach(t => {
      const generatedFromTree = normalizeInput(t.output);
      expect(generatedFromTree).toBe(runLoader(t.input));
    });
  });

  it('complexRealTransform', () => {
    const inp = readFile('transforms/complexRealIn');
    const out = readFile('transforms/complexRealOut');
    const generatedFromTree = normalizeInput(out);
    expect(generatedFromTree).toBe(runLoader(inp));

    let inpES6 = readFile('transforms/complexRealInES6');
    let outES6 = readFile('transforms/complexRealOutES6');
    let generatedFromTreeES6 = normalizeInput(outES6);
    expect(generatedFromTreeES6).toBe(runLoader(inpES6));

    inpES6 = readFile('transforms/complexFlowRealInES6');
    outES6 = readFile('transforms/complexFlowRealOutES6');
    generatedFromTreeES6 = normalizeInput(outES6);
    expect(generatedFromTreeES6).toBe(runLoader(inpES6));
  });
  //
  it('mediaQuery', () => {
    const inp = readFile('transforms/mediaQueryIn');
    const out = readFile('transforms/mediaQueryOut');
    const generatedFromTree = normalizeInput(out);
    expect(generatedFromTree).toBe(runLoader(inp));
  });

  const simple = [];
  simple.push({
    input: readFile('simple/simpleIn'),
    output: readFile('simple/simpleOut')
  });
  simple.push({
    input: readFile('simple/simpleES6In'),
    output: readFile('simple/simpleES6Out')
  });
  simple.push({
    input: readFile('simple/simpleOverrideIn'),
    output: readFile('simple/simpleOverrideOut')
  });

  it('simple', () => {
    simple.forEach(t => {
      const generatedFromTree = normalizeInput(t.output);
      expect(generatedFromTree).toBe(runLoader(t.input));
    });
  });
  //
  it('webpack', () => {
    const inp = readFile('webpackIn');
    const out = readFile('webpackOut');
    const generatedFromTree = normalizeInput(out);
    expect(generatedFromTree).toBe(runLoader(inp));
  });
});

==> inline-css-loader-2.1.1.tgz: package/lib/__tests__/main.js <==
'use strict';

var _ = require('..');

var _2 = _interopRequireDefault(_);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _babylon = require('babylon');

var _babelGenerator = require('babel-generator');

var _babelGenerator2 = _interopRequireDefault(_babelGenerator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getTree(input) {
  return (0, _babylon.parse)(input, {
    sourceType: 'module',
    plugins: _2.default.enabledPlugins
  });
}


function normalizeInput(input) {
  return (0, _babelGenerator2.default)(getTree(input), {
    minified: true
  }, input).code;
}

function runLoader(input) {
  return _2.default.call({
    generateOptions: {
      minified: true,
      quotes: 'single'
    }
  }, input);
}

function readFile(filePath) {
  return _fs2.default.readFileSync(_path2.default.resolve(__dirname, `${ filePath }.txt`), { encoding: 'utf8' });
}

describe('HandPicked', () => {
  const fullparseCode = [];
  fullparseCode.push(readFile('fullObjects/simple'));
  fullparseCode.push(readFile('fullObjects/spread'));
  fullparseCode.push(readFile('fullObjects/media'));
  it('parseCode, doNothing', () => {
    fullparseCode.forEach(obj => {
      const generatedFromTree = normalizeInput(obj);
      expect(generatedFromTree).toBe(runLoader(obj));
    });
  });

  it('temp', () => {
    const temp = {
      input: readFile('transforms/complexIn'),
      output: readFile('transforms/complexOut')
    };
    const generatedFromTree = normalizeInput(temp.output);
    expect(generatedFromTree).toBe(runLoader(temp.input));
  });
  //
  const transforms = [];
  transforms.push({
    input: readFile('transforms/simpleIn'),
    output: readFile('transforms/simpleOut')
  });
  transforms.push({
    input: readFile('transforms/spreadIn'),
    output: readFile('transforms/spreadOut')
  });
  transforms.push({
    input: readFile('transforms/complexIn'),
    output: readFile('transforms/complexOut')
  });
  transforms.push({
    input: readFile('transforms/realIn'),
    output: readFile('transforms/realOut')
  });

  it('transforms', () => {
    transforms.forEach(t => {
      const generatedFromTree = normalizeInput(t.output);
      expect(generatedFromTree).toBe(runLoader(t.input));
    });
  });

  it('complexRealTransform', () => {
    const inp = readFile('transforms/complexRealIn');
    const out = readFile('transforms/complexRealOut');
    const generatedFromTree = normalizeInput(out);
    expect(generatedFromTree).toBe(runLoader(inp));

    let inpES6 = readFile('transforms/complexRealInES6');
    let outES6 = readFile('transforms/complexRealOutES6');
    let generatedFromTreeES6 = normalizeInput(outES6);
    expect(generatedFromTreeES6).toBe(runLoader(inpES6));

    inpES6 = readFile('transforms/complexFlowRealInES6');
    outES6 = readFile('transforms/complexFlowRealOutES6');
    generatedFromTreeES6 = normalizeInput(outES6);
    expect(generatedFromTreeES6).toBe(runLoader(inpES6));
  });
  //
  it('mediaQuery', () => {
    const inp = readFile('transforms/mediaQueryIn');
    const out = readFile('transforms/mediaQueryOut');
    const generatedFromTree = normalizeInput(out);
    expect(generatedFromTree).toBe(runLoader(inp));
  });

  const simple = [];
  simple.push({
    input: readFile('simple/simpleIn'),
    output: readFile('simple/simpleOut')
  });
  simple.push({
    input: readFile('simple/simpleES6In'),
    output: readFile('simple/simpleES6Out')
  });
  simple.push({
    input: readFile('simple/simpleOverrideIn'),
    output: readFile('simple/simpleOverrideOut')
  });

  it('simple', () => {
    simple.forEach(t => {
      const generatedFromTree = normalizeInput(t.output);
      expect(generatedFromTree).toBe(runLoader(t.input));
    });
  });
  //
  it('webpack', () => {
    const inp = readFile('webpackIn');
    const out = readFile('webpackOut');
    const generatedFromTree = normalizeInput(out);
    expect(generatedFromTree).toBe(runLoader(inp));
  });
});

describe('real Examples', () => {
  const tests = _fs2.default.readdirSync(_path2.default.resolve(__dirname, 'real'));
  tests.map(testFolder => ({
    name: testFolder,
    inp: readFile(`real/${ testFolder }/input`),
    out: readFile(`real/${ testFolder }/output`)
  })).forEach(testFolder => {
    it(testFolder.name, () => {
      const out = normalizeInput(testFolder.out);
      expect(out).toBe(runLoader(testFolder.inp));
    });
  });
});
